@@ -1171,10 +1171,13 @@ clientSetNetActions (Client * c)
 
     /* Actions available for all */
     atoms[i++] = display_info->atoms[NET_WM_ACTION_CLOSE];
-    atoms[i++] = display_info->atoms[NET_WM_ACTION_ABOVE];
-    atoms[i++] = display_info->atoms[NET_WM_ACTION_BELOW];
 
     /* Actions depending on the window type and current status */
+    if (c->type & WINDOW_REGULAR_FOCUSABLE)
+    {
+        atoms[i++] = display_info->atoms[NET_WM_ACTION_ABOVE];
+        atoms[i++] = display_info->atoms[NET_WM_ACTION_BELOW];
+    }
     if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_VISIBLE))
     {
         atoms[i++] = display_info->atoms[NET_WM_ACTION_FULLSCREEN];
@@ -1332,6 +1335,14 @@ clientWindowType (Client * c)
                 XFWM_FLAG_HAS_BORDER | XFWM_FLAG_HAS_HIDE |
                 XFWM_FLAG_HAS_MENU | XFWM_FLAG_HAS_MOVE |
                 XFWM_FLAG_HAS_RESIZE);
+            /* Treat SPLASHSCREEN as transient for group to work around
+             * broken apps placing splashscreens above and then complaining
+             * it hides their dialogs, sigh.
+             */
+            if ((c->transient_for == None) || (!clientGetTransient (c)))
+            {
+                c->transient_for = c->screen_info->xroot;
+            }
         }
         else if (c->type_atom == display_info->atoms[NET_WM_WINDOW_TYPE_NOTIFICATION])
         {
@@ -1446,7 +1457,9 @@ clientHandleNetActiveWindow (Client *c, guint32 timestamp, gboolean source_is_ap
         current_time = myDisplayGetLastUserTime (display_info);
 
         TRACE ("time of event received is %u, current XServer time is %u", (guint32) ev_time, (guint32) current_time);
-        if ((screen_info->params->prevent_focus_stealing) && TIMESTAMP_IS_BEFORE((guint32) ev_time, (guint32) current_time))
+        if ((screen_info->params->prevent_focus_stealing) &&
+            (TIMESTAMP_IS_BEFORE((guint32) ev_time, (guint32) current_time) ||
+             (screen_info->params->activate_action == ACTIVATE_ACTION_NONE)))
         {
             focused = clientGetFocus ();
             /* We do not want to set the demand attention flag if the window is focused though */
